aboutsummaryrefslogtreecommitdiffstats
path: root/website/host-scripts
diff options
context:
space:
mode:
Diffstat (limited to 'website/host-scripts')
-rwxr-xr-xwebsite/host-scripts/upload-website.sh14
1 files changed, 7 insertions, 7 deletions
diff --git a/website/host-scripts/upload-website.sh b/website/host-scripts/upload-website.sh
index eec2061f..35613402 100755
--- a/website/host-scripts/upload-website.sh
+++ b/website/host-scripts/upload-website.sh
@@ -1,20 +1,20 @@
#! /bin/sh
# Script to upload fetchmail website from SVN repository
# (C) 2008 - 2009 by Matthias Andree. GNU GPL v3.
: ${BERLIOS_LOGIN=m-a}
# abort on error
-set -e
+set -eu
# cd to parent of script
-cd $(dirname "$0")
+cd "$(dirname "$0")"
cd ..
echo "==> Running sanity checks"
# make sure we have no dangling symlinks
-if file * | egrep broken\|dangling ; then
+if LC_ALL=C file * | egrep broken\|dangling ; then
echo "broken symlinks -> abort" >&2
exit 1
fi
@@ -27,7 +27,7 @@ rsync \
--chmod=ug=rwX,o=rX,Dg=s --perms \
--copy-links --times --checksum --verbose \
--exclude host-scripts \
- --exclude .svn --exclude '*~' --exclude '#*#' \
+ --exclude .git --exclude '*~' --exclude '#*#' \
* \
"$BERLIOS_LOGIN@shell.berlios.de:/home/groups/fetchmail/htdocs/" &
pids="$pids $!"
@@ -37,7 +37,7 @@ rsync \
--chmod=ug=rwX,o=rX,Dg=s --perms \
--copy-links --times --checksum --verbose \
--exclude host-scripts \
- --exclude .svn --exclude '*~' --exclude '#*#' \
+ --exclude .git --exclude '*~' --exclude '#*#' \
* \
$HOME/public_html/fetchmail/info/ &
pids="$pids $!"
@@ -1,20 +1,20 @@
#! /bin/sh
-# Script to upload fetchmail website from SVN repository
-# (C) 2008 - 2009 by Matthias Andree. GNU GPL v3.
+# Script to upload fetchmail website from Git repository
+# (C) 2008 - 2010 by Matthias Andree. GNU GPL v3.
: ${BERLIOS_LOGIN=m-a}
# abort on error